@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: build_boilerplate2.py 11479 2019-04-22 11:33:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
-# $Revision: 11436 $
+# $Date: 2019-04-22 20:33:41 +0900 (週一, 22 四月 2019) $
+# $Revision: 11479 $
 
 import os
 import re
@@ -150,7 +150,7 @@ class Command(BaseCommand):
                             continue
 
                         # etree ------------------------------------------------
-                        page = parse(f)
+                        page = parse(f, features='html5lib')
                         
                         # replace word
                         self.changeWordToMd5(page)
