@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11461 2019-04-16 18:26:42Z Lavender $
+# $Id: setup.py 11474 2019-04-20 18:48:58Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-17 03:26:42 +0900 (週三, 17 四月 2019) $
-# $Revision: 11461 $
+# $Date: 2019-04-21 03:48:58 +0900 (週日, 21 四月 2019) $
+# $Revision: 11474 $
 
 import os
 import sys
@@ -372,7 +372,7 @@ if __name__ == "__main__":
                 command = "djangocms -f -p \"%s\" \"%s\"" % (
                     path, projectName)
                     
-            if local and local in ["zh_TW", "zh_Hant"]:
+            if local and local.upper() in ["ZH_TW", "ZH_HANT"]:
                 command = "%s --languages=zh-hant" % command
                 
             result = os.system(command)
