@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11190 2018-08-05 13:08:39Z Lavender $
+# $Id: cms_plugins.py 11489 2019-04-24 06:45:44Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-05 22:08:39 +0900 (週日, 05 八月 2018) $
-# $Revision: 11190 $
+# $Date: 2019-04-24 15:45:44 +0900 (週三, 24 四月 2019) $
+# $Revision: 11489 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -40,7 +40,7 @@ class CMSCommentPlugin(CMSPluginBase):
         request = context['request']
         url = request.build_absolute_uri(request.path)
 
-        comments = Comment.objects.filter(url=url)
+        comments = Comment.objects.filter(url=url, display=True)
 
         obj, created = CommentConfig.objects.get_or_create(
             url=url,
