@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11190 2018-08-05 13:08:39Z Lavender $
+# $Id: models.py 11489 2019-04-24 06:45:44Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-08-05 22:08:39 +0900 (週日, 05 八月 2018) $
-# $Revision: 11190 $
+# $Date: 2019-04-24 15:45:44 +0900 (週三, 24 四月 2019) $
+# $Revision: 11489 $
 
 import datetime
 
@@ -51,6 +51,14 @@ class Comment(models.Model):
     message = models.TextField()
 
     createDate = models.DateTimeField(auto_now_add=True)
+    display = models.BooleanField(default=True)
+    
+    @property
+    def username(self):
+        if self.user:
+            return self.user.username
+        else:
+            return self.email
 
 class CommentConfig(models.Model):
     url = models.CharField(max_length=400, editable=False, null=True)
