@@ -38,7 +38,7 @@ def commentCount(context, url=None):
     if obj.useFbComment:
         count = getApiData(url, "comment_count")
     else:
-        count = Comment.objects.filter(url=url).count()
+        count = Comment.objects.filter(url=url, display=True).count()
     
     if count:
         return count
