@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 11388 2019-03-20 08:36:54Z Lavender $
+# $Id: urls.py 11489 2019-04-24 06:45:44Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-03-20 17:36:54 +0900 (週三, 20 三月 2019) $
-# $Revision: 11388 $ 
+# $Date: 2019-04-24 15:45:44 +0900 (週三, 24 四月 2019) $
+# $Revision: 11489 $ 
 
 from django.conf.urls import url
 
@@ -22,5 +22,7 @@ from . import views
 #app_name = 'comment'
 
 urlpatterns = [
-    url(r'^comment/add$', views.CommentView.as_view(), name='addComment'),
+    url(r'^comments/add$', views.CommentView.as_view(), name='addComment'),
+    url(r'^comments/(?P<pk>\d+)/hide$', 
+        views.CommentHideView.as_view(), name='hideComment'),
 ]
