@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: views.py 11491 2019-04-24 06:57:13Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2019-04-24 15:57:13 +0900 (週三, 24 四月 2019) $
+# $Revision: 11491 $
 
 from django.views.generic import View
 from django.shortcuts import redirect, get_object_or_404
@@ -41,4 +41,16 @@ class CommentView(View):
                 message=message,
             )
         comment.save()
-        return redirect(url)
\ No newline at end of file
+        return redirect(url)
+        
+class CommentHideView(View):  
+    def post(self, request, *args, **kwargs):
+        pk = kwargs["pk"]
+        
+        comment = get_object_or_404(Comment, id=pk)
+        
+        if request.user.is_staff:
+            comment.display = False
+            comment.save()
+        return redirect(comment.url)
+        
\ No newline at end of file
